@@ -653,6 +653,65 @@ class DownloadMixin(_RestObjectBase):
         )
 
 
+class RotateMixin(_RestManagerBase):
+    _computed_path: Optional[str]
+    _from_parent_attrs: Dict[str, Any]
+    _obj_cls: Optional[Type[base.RESTObject]]
+    _parent: Optional[base.RESTObject]
+    _parent_attrs: Dict[str, Any]
+    _path: Optional[str]
+    gitlab: gitlab.Gitlab
+
+    @exc.on_http_error(exc.GitlabRotateError)
+    def rotate(
+        self, id: Union[str, int], expires_at: Optional[str] = None, **kwargs: Any
+    ) -> Dict[str, Any]:
+        """Rotate an access token.
+
+        Args:
+            id: ID of the token to rotate
+            **kwargs: Extra options to send to the server (e.g. sudo)
+
+        Raises:
+            GitlabAuthenticationError: If authentication is not correct
+            GitlabRotateError: If the server cannot perform the request
+        """
+        path = f"{self.path}/{utils.EncodedId(id)}/rotate"
+        data: Dict[str, Any] = {}
+        if expires_at is not None:
+            data = {"expires_at": expires_at}
+
+        server_data = self.gitlab.http_post(path, post_data=data, **kwargs)
+        if TYPE_CHECKING:
+            assert not isinstance(server_data, requests.Response)
+        return server_data
+
+
+class ObjectRotateMixin(_RestObjectBase):
+    _id_attr: Optional[str]
+    _attrs: Dict[str, Any]
+    _module: ModuleType
+    _parent_attrs: Dict[str, Any]
+    _updated_attrs: Dict[str, Any]
+    manager: base.RESTManager
+
+    def rotate(self, **kwargs: Any) -> None:
+        """Rotate the current access token object.
+
+        Args:
+            **kwargs: Extra options to send to the server (e.g. sudo)
+
+        Raises:
+            GitlabAuthenticationError: If authentication is not correct
+            GitlabRotateError: If the server cannot perform the request
+        """
+        if TYPE_CHECKING:
+            assert isinstance(self.manager, RotateMixin)
+            assert self.encoded_id is not None
+        server_data = self.manager.rotate(self.encoded_id, **kwargs)
+        self._update_attrs(server_data)
+
+
 class SubscribableMixin(_RestObjectBase):
     _id_attr: Optional[str]
     _attrs: Dict[str, Any]
@@ -944,3 +1003,73 @@ class PromoteMixin(_RestObjectBase):
         if TYPE_CHECKING:
             assert not isinstance(result, requests.Response)
         return result
+
+
+class UploadMixin(_RestObjectBase):
+    _id_attr: Optional[str]
+    _attrs: Dict[str, Any]
+    _module: ModuleType
+    _parent_attrs: Dict[str, Any]
+    _updated_attrs: Dict[str, Any]
+    _upload_path: str
+    manager: base.RESTManager
+
+    def _get_upload_path(self) -> str:
+        """Formats _upload_path with object attributes.
+
+        Returns:
+            The upload path
+        """
+        if TYPE_CHECKING:
+            assert isinstance(self._upload_path, str)
+        data = self.attributes
+        return self._upload_path.format(**data)
+
+    @cli.register_custom_action(("Project", "ProjectWiki"), ("filename", "filepath"))
+    @exc.on_http_error(exc.GitlabUploadError)
+    def upload(
+        self,
+        filename: str,
+        filedata: Optional[bytes] = None,
+        filepath: Optional[str] = None,
+        **kwargs: Any,
+    ) -> Dict[str, Any]:
+        """Upload the specified file.
+
+        .. note::
+
+            Either ``filedata`` or ``filepath`` *MUST* be specified.
+
+        Args:
+            filename: The name of the file being uploaded
+            filedata: The raw data of the file being uploaded
+            filepath: The path to a local file to upload (optional)
+
+        Raises:
+            GitlabAuthenticationError: If authentication is not correct
+            GitlabUploadError: If the file upload fails
+            GitlabUploadError: If ``filedata`` and ``filepath`` are not
+                specified
+            GitlabUploadError: If both ``filedata`` and ``filepath`` are
+                specified
+
+        Returns:
+            A ``dict`` with info on the uploaded file
+        """
+        if filepath is None and filedata is None:
+            raise exc.GitlabUploadError("No file contents or path specified")
+
+        if filedata is not None and filepath is not None:
+            raise exc.GitlabUploadError("File contents and file path specified")
+
+        if filepath is not None:
+            with open(filepath, "rb") as f:
+                filedata = f.read()
+
+        file_info = {"file": (filename, filedata)}
+        path = self._get_upload_path()
+        server_data = self.manager.gitlab.http_post(path, files=file_info, **kwargs)
+
+        if TYPE_CHECKING:
+            assert isinstance(server_data, dict)
+        return server_data
